@@ -34,11 +34,39 @@
 			foreach ($list as $name => $item) {
 				$this->output->add_tag("item", $name, array(
 					"count"  => $item["today"],
-					"change" => $item["change"]));
+					"change" => sprintf("%0.1f", $item["change"])));
 			}
 			$this->output->close_tag();
 		}
 
+		private function show_hiawatha_weblog() {
+			if ($this->output->fetch_from_cache("weblog")) {
+				return;
+			}
+
+			$hostname = "www.hiawatha-webserver.org";
+			$hiawatha_website = new HTTPS($hostname);
+			if (($result = $hiawatha_website->GET("/weblog?output=xml")) == false) {
+				return;
+			}
+
+			if (substr($result["headers"]["content-type"], 0, 8) != "text/xml") {
+				return;
+			}
+
+			$result["body"] = str_replace("&lt;img src=&quot;/", "&lt;img src=&quot;https://".$hostname."/", $result["body"]);
+			$result["body"] = str_replace("&lt;a href=&quot;/", "&lt;a href=&quot;https://".$hostname."/", $result["body"]);
+
+			$xml = new DomDocument();
+			if ($xml->loadXML($result["body"]) == false) {
+				return;
+			}
+
+			$this->output->start_caching("weblog", 300);
+			$this->output->add_xml($xml, "weblogs");
+			$this->output->stop_caching();
+		}
+
 		public function execute() {
 			if ($this->page->ajax_request) {
 				if ($this->page->pathinfo[1] == null) {
@@ -69,6 +97,9 @@
 			if (($webservers = $this->model->get_webservers()) === false) {
 				return;
 			}
+			if (count($webservers) == 0) {
+				$this->output->add_system_message("No webservers have been configured yet. ".($this->user->is_admin ? "Add them via the Webserver administration page in the CMS." : "Ask an administrator to add them for you."));
+			}
 
 			$webservers_offline = false;
 
@@ -94,7 +125,10 @@
 
 				if ($webserver["version"] != "") {
 					$parts = explode(",", $webserver["version"]);
-					list(, $version) = explode("v", $parts[0], 2);
+
+					$webserver["version"] = array_shift($parts);
+					$webserver["modules"] = $parts;
+					list(, $version) = explode("v", $webserver["version"], 2);
 					$comparison = version_compare($version, $_SESSION["latest_hiawatha_version"], ">=");
 					$webserver["uptodate"] = show_boolean($comparison);
 
@@ -108,7 +142,19 @@
 					}
 				}
 
-				$this->output->record($webserver, "webserver");
+				$this->output->open_tag("webserver", array("id" => $webserver["id"]));
+
+				$this->output->record($webserver);
+
+				if (is_array($webserver["modules"])) {
+					$this->output->open_tag("modules");
+					foreach ($webserver["modules"] as $module) {
+						$this->output->add_tag("module", trim($module));
+					}
+					$this->output->close_tag();
+				}
+
+				$this->output->close_tag();
 			}
 
 			if ($webservers_offline) {
@@ -124,6 +170,10 @@
 			$this->output->add_tag("threshold_change", $this->settings->dashboard_threshold_change);
 			$this->output->add_tag("threshold_value", $this->settings->dashboard_threshold_value);
 			$this->output->add_tag("page_refresh", $this->settings->dashboard_page_refresh);
+
+			if ($this->settings->dashboard_show_weblog) {
+				$this->show_hiawatha_weblog();
+			}
 		}
 	}
 ?>
