@@ -12,6 +12,8 @@
 					$this->model->import_sql();
 				} else if ($_POST["submit_button"] == "Update database") {
 					$this->model->update_database();
+				} else if ($_POST["submit_button"] == "Set password") {
+					$this->model->set_admin_credentials($_POST["username"], $_POST["password"], $_POST["repeat"]);
 				}
 			}
 
@@ -39,6 +41,17 @@
 				case "update_db":
 					ob_clean();
 					break;
+                case "credentials":
+					$this->output->add_javascript("banshee/".PASSWORD_HASH.".js");
+					$this->output->add_javascript("setup.js");
+					$this->output->run_javascript("hash = window['".PASSWORD_HASH."'];");
+
+					if ($_POST["submit_button"] != "Set password") {
+						$_POST["username"] = "admin";
+					}
+					$this->output->add_tag("username", $_POST["username"]);
+					ob_clean();
+					break;
 				case "done":
 					break;
 			}
