@@ -1,5 +1,5 @@
 <?php
-	/* libraries/oo/controller.php
+	/* libraries/controller.php
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
@@ -7,29 +7,35 @@
 	 */
 
 	abstract class controller {
+		protected $model = null;
 		protected $db = null;
 		protected $settings = null;
 		protected $user = null;
 		protected $page = null;
 		protected $output = null;
-		protected $model = null;
+		protected $language = null;
 
 		/* Constructor
 		 *
-		 * INPUT:  object database, object settings, object user, object page, object output
+		 * INPUT:  object database, object settings, object user, object page, object output[, object language]
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function __construct($db, $settings, $user, $page, $output) {
-			$this->db = $db;
+		public function __construct($database, $settings, $user, $page, $output, $language = null) {
+			$this->db = $database;
 			$this->settings = $settings;
 			$this->user = $user;
 			$this->page = $page;
 			$this->output = $output;
+			$this->language = $language;
 
-			$class = str_replace("/", "_", $page->module)."_model";
-			if (class_exists($class)) {
-				$this->model = new $class($db, $settings, $user, $page, $output);
+			$model_class = str_replace("/", "_", $page->module)."_model";
+			if (class_exists($model_class)) {
+				if (is_subclass_of($model_class, "model") == false) {
+					print "Model class '".$model_class."' does not extend class 'model'.\n";
+				} else {
+					$this->model = new $model_class($database, $settings, $user, $page, $output, $language);
+				}
 			}
 		}
 
