@@ -13,6 +13,7 @@
 		private $open_tags = array();
 		private $cache = null;
 		private $cache_key = null;
+		private $cache_timeout = null;
 		private $cache_buffer = "";
 		private $tag_eol = true;
 
@@ -316,16 +317,17 @@
 
 		/* Start caching XML additions done after this call
 		 *
-		 * INPUT:  string cache key
+		 * INPUT:  string cache key[, int cache timeout]
 		 * OUTPUT: true
 		 * ERROR:  false
 		 */
-		public function start_caching($key) {
+		public function start_caching($key, $timeout = null) {
 			if (($this->cache === null) || ($this->cache_key !== null)) {
 				return false;
 			}
 
 			$this->cache_key = $key;
+			$this->cache_timeout = $timeout;
 
 			return true;
 		}
@@ -341,8 +343,9 @@
 				return false;
 			}
 
-			$this->cache->{$this->cache_key} = $this->cache_buffer;
+			$this->cache->store($this->cache_key, $this->cache_buffer, $this->cache_timeout);
 			$this->cache_key = null;
+			$this->cache_timeout = null;
 			$this->cache_buffer = "";
 
 			return true;
@@ -360,6 +363,7 @@
 			}
 
 			$this->cache_key = null;
+			$this->cache_timeout = null;
 			$this->cache_buffer = "";
 
 			return true;
