@@ -38,6 +38,11 @@
 				return "update_db";
 			}
 
+			$result = $db->execute("select password from users where username=%s", "admin");
+			if ($result[0]["password"] == "none") {
+				return "credentials";
+			}
+
 			return "done";
 		}
 
@@ -217,12 +222,13 @@
 					$this->db->query("alter table %S drop %S", $table, "timestamp_end");
 				}
 
-				$this->db->query("alter table %S add index(%S)", "cgi_statistics", "date");
-				$this->db->query("alter table %S add index(%S)", "cgi_statistics", "hour");
-				$this->db->query("alter table %S add index(%S)", "host_statistics", "date");
-				$this->db->query("alter table %S add index(%S)", "host_statistics", "hour");
-				$this->db->query("alter table %S add index(%S)", "server_statistics", "date");
-				$this->db->query("alter table %S add index(%S)", "server_statistics", "hour");
+				$query = "alter table %S add index(%S)";
+				$this->db->query($query, "cgi_statistics", "date");
+				$this->db->query($query, "cgi_statistics", "hour");
+				$this->db->query($query, "host_statistics", "date");
+				$this->db->query($query, "host_statistics", "hour");
+				$this->db->query($query, "server_statistics", "date");
+				$this->db->query($query, "server_statistics", "hour");
 
 				$this->settings->dashboard_threshold_change = 150;
 				$this->settings->dashboard_threshold_value = 5;
@@ -239,6 +245,52 @@
 			if ($this->settings->database_version < 104) {
 				$this->settings->database_version = 104;
 			}
+
+			if ($this->settings->database_version < 105) {
+				$this->db->query("alter table %S change %S %S varchar(128) character set utf8 collate utf8_general_ci not null", "sessions", "session_id", "session_id");
+
+				$query = "update settings set type=%s value=%s where %S=%s";
+				$this->db->query($query, "float", "2.5", "key", "dashboard_threshold_change");
+				$this->db->query($query, "float", "5",   "key", "report_alert_high");
+				$this->db->query($query, "float", "2",   "key", "report_alert_medium");
+
+				$this->settings->dashboard_show_weblog = true;
+
+				$this->settings->database_version = 105;
+			}
+		}
+
+		/* Set administrator password
+		 */
+		public function set_admin_credentials($username, $password, $repeat) {
+			$result = true;
+
+			if (valid_input($username, VALIDATE_LETTERS, VALIDATE_NONEMPTY) == false) {
+				$this->output->add_message("The username must consist of lowercase letters.");
+				$result = false;
+			}
+
+			if ($password != $repeat) {
+				$this->output->add_message("The passwords do not match.");
+				$result = false;
+			}
+
+			if ($result == false) {
+				return false;
+			}
+
+			if (is_false($_POST["password_hashed"])) {
+				$password = hash(PASSWORD_HASH, $password.hash(PASSWORD_HASH, $username));
+				$repeat   = hash(PASSWORD_HASH, $repeat.hash(PASSWORD_HASH, $username));
+			}
+
+			$query = "update users set username=%s, password=%s, status=%d where username=%s";
+			if ($this->db->query($query, $username, $password, USER_STATUS_ACTIVE, "admin") === false) {
+				$this->output->add_message("Error while setting password.");
+				return false;
+			}
+
+			return true;
 		}
 	}
 
